;; Generated package description from wgrep.el  -*- no-byte-compile: t -*-
(define-package "wgrep" "3.0.0" "Writable grep buffer and apply the changes to files" '((emacs "25.1")) :commit "2d1c0509215499e927817b0d7d3f133db678e010" :authors '(("Masahiro Hayashi" . "mhayashi1120@gmail.com")) :maintainer '("Masahiro Hayashi" . "mhayashi1120@gmail.com") :keywords '("grep" "edit" "extensions") :url "http://github.com/mhayashi1120/Emacs-wgrep/raw/master/wgrep.el")
